Models
======

AbstractModel
-------------
.. autoclass:: bamboo.models.abstract_model.AbstractModel
    :members:

Calculation
-----------
.. autoclass:: bamboo.models.calculation.Calculation
    :members:

Dataset
-------
.. autoclass:: bamboo.models.dataset.Dataset
    :members:

Observation
-----------
.. autoclass:: bamboo.models.observation.Observation
    :members:
